==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/UserSchemaDefinitions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.UserSchemaBase;
import com.okta.sdk.resource.model.UserSchemaPublic;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserSchemaDefinitions
 */
@JsonPropertyOrder({ UserSchemaDefinitions.JSON_PROPERTY_BASE, UserSchemaDefinitions.JSON_PROPERTY_CUSTOM })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserSchemaDefinitions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BASE = "base";
    private UserSchemaBase base;

    public static final String JSON_PROPERTY_CUSTOM = "custom";
    private UserSchemaPublic custom;

    public UserSchemaDefinitions() {
    }

    public UserSchemaDefinitions base(UserSchemaBase base) {

        this.base = base;
        return this;
    }

    /**
     * Get base
     *
     * @return base
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_BASE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserSchemaBase getBase() {
        return base;
    }

    @JsonProperty(JSON_PROPERTY_BASE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setBase(UserSchemaBase base) {
        this.base = base;
    }

    public UserSchemaDefinitions custom(UserSchemaPublic custom) {

        this.custom = custom;
        return this;
    }

    /**
     * Get custom
     *
     * @return custom
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CUSTOM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserSchemaPublic getCustom() {
        return custom;
    }

    @JsonProperty(JSON_PROPERTY_CUSTOM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCustom(UserSchemaPublic custom) {
        this.custom = custom;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserSchemaDefinitions userSchemaDefinitions = (UserSchemaDefinitions) o;
        return Objects.equals(this.base, userSchemaDefinitions.base)
                && Objects.equals(this.custom, userSchemaDefinitions.custom);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(base, custom);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserSchemaDefinitions {\n");
        sb.append("    base: ").append(toIndentedString(base)).append("\n");
        sb.append("    custom: ").append(toIndentedString(custom)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/UserSchemaDefinitions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.UserSchemaBase;
import com.okta.sdk.resource.model.UserSchemaPublic;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserSchemaDefinitions
 */
@JsonPropertyOrder({ UserSchemaDefinitions.JSON_PROPERTY_BASE, UserSchemaDefinitions.JSON_PROPERTY_CUSTOM })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class UserSchemaDefinitions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BASE = "base";
    private UserSchemaBase base;

    public static final String JSON_PROPERTY_CUSTOM = "custom";
    private UserSchemaPublic custom;

    public UserSchemaDefinitions() {
    }

    public UserSchemaDefinitions base(UserSchemaBase base) {

        this.base = base;
        return this;
    }

    /**
     * Get base
     *
     * @return base
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_BASE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserSchemaBase getBase() {
        return base;
    }

    @JsonProperty(JSON_PROPERTY_BASE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setBase(UserSchemaBase base) {
        this.base = base;
    }

    public UserSchemaDefinitions custom(UserSchemaPublic custom) {

        this.custom = custom;
        return this;
    }

    /**
     * Get custom
     *
     * @return custom
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CUSTOM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserSchemaPublic getCustom() {
        return custom;
    }

    @JsonProperty(JSON_PROPERTY_CUSTOM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCustom(UserSchemaPublic custom) {
        this.custom = custom;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserSchemaDefinitions userSchemaDefinitions = (UserSchemaDefinitions) o;
        return Objects.equals(this.base, userSchemaDefinitions.base)
                && Objects.equals(this.custom, userSchemaDefinitions.custom);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(base, custom);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserSchemaDefinitions {\n");
        sb.append("    base: ").append(toIndentedString(base)).append("\n");
        sb.append("    custom: ").append(toIndentedString(custom)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
